#!/bin/bash
#
# Handle RPM installation and uninstallation, starting and stopping
# Pegasus as necessary.

RETVAL=0
PREFIX=$2

install_rpm() {

	# Start pegasus, if not already started

	$PREFIX/bin/start_pegasus.sh

	# Install CIM schema in root/hpq namespace
 	echo "Installing WBEM Provider schema. This may take a few minutes."
	echo -n "."

	cimmof -uc -w -n root/hpq -I $PREFIX/mof/CIM2191 \
		$PREFIX/mof/CIM2191/cim_schema_2.19.1.mof


	# Install needed CIM schema in root/interop namespace
	echo -n "."

	cimmof -uc -w -n root/interop -I $PREFIX/mof/CIM2191 \
        $PREFIX/mof/cimv2191-coreinterop.mof

	# Install Qualifiers and SMX schema in root/hpq namespace
	echo -n "."

    cimmof -aE -uc -w -n root/hpq $PREFIX/mof/root/hpq/SMXQualifiers.mof

	for class in `cat $PREFIX/mof/moflist.root\#hpq`; do
		cimmof -aE -uc -w -n root/hpq -I $PREFIX/mof/root/hpq \
			$PREFIX/mof/root/hpq/$class.mof
	done

	# Install SMX schema in root/interop namespace
	echo -n "."

    cimmof -aE -uc -w -n root/interop $PREFIX/mof/root/hpq/SMXQualifiers.mof

	for class in `cat $PREFIX/mof/moflist.root\#interop`; do
		cimmof -uc -n root/interop -I $PREFIX/mof/root/interop \
	        	$PREFIX/mof/root/interop/$class.mof
	done	

	# Run ldconfig to update our entry in /etc/ld.so.conf.d

	ldconfig

	# Register providers
	echo "."

	cimmof -n root/PG_InterOp $PREFIX/reg/*R.mof

	# Create SMX_AutoStart indication subscription

        /opt/hp/hp-smx/bin/mkautostart

	# Stop pegasus, if started it

	$PREFIX/bin/stop_pegasus.sh
}

uninstall_rpm() {

	# Start pegasus, if not already started

	$PREFIX/bin/start_pegasus.sh

	# Remove all indication subscriptions

	/opt/hp/hp-smx/bin/rmsubs -y

	# Uninstall SMX schema in root/interop namespace
 	echo "Uninstalling WBEM Provider schema. This may take a few minutes."

	echo -n "."
	for class in `cat $PREFIX/mof/moflist-reversed.root\#interop`; do
        	$PREFIX/bin/deleteclass.sh -n root/interop $class
	done	

	# Uninstall SMX schema in root/hpq namespace
	echo -n "."

	for class in `cat $PREFIX/mof/moflist-reversed.root\#hpq`; do
		# Avoid duplicate erase, also prevent CIM_ERR_CLASS_HAS_CHILDREN message shows. 
		dupclass=""
		classpre=`echo $class | awk -F'_' '{print $1}'`
		[ "$classpre" == "CIM" ] && dupclass=`cat $PREFIX/mof/cimv2191moflist-reversed.root\#hpq | grep ^$class$`
        	[ "$dupclass" == "" ] && $PREFIX/bin/deleteclass.sh -n root/hpq $class
	done

	# Uninstall CIM schema in root/hpq namespace
	echo -n "."

	for class in `cat $PREFIX/mof/cimv2191moflist-reversed.root\#hpq`; do
        	$PREFIX/bin/deleteclass.sh -n root/hpq $class
	done

	# Uninstall CIM schema in root/interop namespace
	echo -n "."

	for class in `cat $PREFIX/mof/cimv2191moflist-reversed.root\#interop`; do
        	$PREFIX/bin/deleteclass.sh -n root/interop $class
	done	


	# Remove providers
	echo -e "."

	for module in `cat $PREFIX/reg/*modulelist`; do
              cimprovider -rm $module > /dev/null
	done

	# Stop pegasus, if started it

	$PREFIX/bin/stop_pegasus.sh
}

case "$1" in

	install|uninstall)
		$1_rpm
        ;;

	*)
		echo "Usage: $0 {install|uninstall} {base directory}"
		RETVAL=2
        ;;
esac

exit $RETVAL
